summaryrefslogtreecommitdiffstats
path: root/fortran/src/H5Af.c
diff options
context:
space:
mode:
Diffstat (limited to 'fortran/src/H5Af.c')
-rw-r--r--fortran/src/H5Af.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/fortran/src/H5Af.c b/fortran/src/H5Af.c
index cc4f932..73cb5cf 100644
--- a/fortran/src/H5Af.c
+++ b/fortran/src/H5Af.c
@@ -813,7 +813,7 @@ done:
/*----------------------------------------------------------------------------
* Name: h5adelete_c
* Purpose: Call H5Adelete2 to delete an attribute
* Inputs: obj_id - object identifier
* name - name of the attribute
* namelen - name length
@@ -835,9 +835,9 @@ nh5adelete_c (hid_t_f *obj_id, _fcd name, size_t_f *namelen)
HGOTO_DONE(FAIL);
/*
- * Call H5Adelete2 function.
+ * Call H5Adelete function.
*/
- if(H5Adelete2((hid_t)*obj_id, ".", c_name, H5P_DEFAULT) < 0)
+ if(H5Adelete((hid_t)*obj_id, c_name) < 0)
HGOTO_DONE(FAIL);
done:
@@ -813,7 +813,7 @@ done:
/*----------------------------------------------------------------------------
* Name: h5adelete_c
- * Purpose: Call H5Adelete2 to delete an attribute
+ * Purpose: Call H5Adelete to delete an attribute
* Inputs: obj_id - object identifier
* name - name of the attribute